#################
ftrack Python API
#################

Python API for ftrack.

.. important::

    This is the new Python client for the ftrack API. If you are migrating from
    the old client then please read the dedicated `migration guide <http://ftrack-python-api.rtd.ftrack.com/en/stable/release/migrating_from_old_api.html>`_.

*************
Documentation
*************

Full documentation, including installation and setup guides, can be found at
http://ftrack-python-api.rtd.ftrack.com/en/stable/

*********************
Copyright and license
*********************

Copyright (c) 2014 ftrack

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this work except in compliance with the License. You may obtain a copy of the
License in the LICENSE.txt file, or at:

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.